==> 0.3.19.tar.gz: android/src/main/java/com/samelement/iot_notification/appwidget/helper/AppWidgetHelper.java <==
package com.samelement.iot_notification.appwidget.helper;

import com.samelement.iot_notification.device.Device;
import com.samelement.iot_notification.device.NodeProperty;
import com.samelement.iot_notification.device.Node;

public class AppWidgetHelper {
    private static String getResourceNameFromDeviceParameter(String parameter) {
        String[] splitted = parameter.split("/");

        return splitted[splitted.length - 1];
    }

    public static NodeProperty getNodePropertyByDeviceParameter(
            String parameter, Device device) {
        String nodeId = getNodeIdFromParameter(parameter);
        String resourceName = getResourceNameFromDeviceParameter(parameter);

        for(Node node : device.getNodes()) {
            if (node.getId().equals(nodeId) && node.getProperties() != null && node.getProperties().size() > 0) {
                for(NodeProperty prop : node.getProperties()) {
                    if (prop.getId().equals(resourceName)) {
                        return prop;
                    }
                }
            }
        }

        return null;
    }

    private static String getNodeIdFromParameter(String parameter) {
        String[] splitted = parameter.split("/");

        // node id with underscore
        String nodeId = splitted[0];
        if (nodeId.contains("_")) {
            String[] splittedNodeId = nodeId.split("_");
            StringBuilder newNodeId = new StringBuilder();
            boolean first = true;
            for (int i = 0; i < splittedNodeId.length - 1; i++) {
                if (first)
                    first = false;
                else
                    newNodeId.append("_");

                newNodeId.append(splittedNodeId[i]);
            }

            nodeId = newNodeId.toString();
        }
        return nodeId;
    }
}

==> 0.5.5.tar.gz: android/src/main/java/com/samelement/iot_notification/appwidget/helper/AppWidgetHelper.java <==
package com.samelement.iot_notification.appwidget.helper;

import com.samelement.iot_notification.device.Device;
import com.samelement.iot_notification.device.NodeProperty;
import com.samelement.iot_notification.device.Node;

public class AppWidgetHelper {
    private static String getResourceNameFromDeviceParameter(String parameter) {
        String[] split = parameter.split("/");

        return split[split.length - 1];
    }

    public static NodeProperty getNodePropertyByDeviceParameter(
            String parameter, Device device) {
        String nodeId = getNodeIdFromParameter(parameter);
        String resourceName = getResourceNameFromDeviceParameter(parameter);

        for(Node node : device.getNodes()) {
            if (node.getId().equals(nodeId) && node.getProperties() != null && node.getProperties().size() > 0) {
                for(NodeProperty prop : node.getProperties()) {
                    if (prop.getId().equals(resourceName)) {
                        return prop;
                    }
                }
            }
        }

        return null;
    }

    private static String getNodeIdFromParameter(String parameter) {
        String[] split = parameter.split("/");

        // node id with underscore
        String nodeId = split[0];
        if (nodeId.contains("_")) {
            String[] splitNodeId = nodeId.split("_");
            StringBuilder newNodeId = new StringBuilder();
            boolean first = true;
            for (int i = 0; i < splitNodeId.length - 1; i++) {
                if (first)
                    first = false;
                else
                    newNodeId.append("_");

                newNodeId.append(splitNodeId[i]);
            }

            nodeId = newNodeId.toString();
        }
        return nodeId;
    }
}
